"""Utility functions for working with Wikidata"""
import requests

__version__ = '0.4'


def get_coordinates_from_wd_point(point_str):
    regex = re.compile("Point\(-?([\d\.]+) (-?[\d\.]+)\)")
    match = regex.match(point_str)
    if match is None:
        return None
    return match.groups()[1], match.groups()[0]


def get_wd_id_from_url(url):
    regex = re.compile("http://www.wikidata.org/entity/(Q\d+)")
    match = regex.match(url)
    if match is None:
        return None
    return match.groups()[0]


def run_query(query):

    url = 'https://query.wikidata.org/sparql'

    r = requests.get(url, params={'format': 'json', 'query': query})
    response_json = r.json()
    return response_json



#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['mkwikidata']

package_data = \
{'': ['*']}

install_requires = \
['requests >=2.25.1']

setup(name='mkwikidata',
      version='0.4',
      description='Utility functions for working with Wikidata',
      author='Maksym Kozlenko',
      author_email='max@kozlenko.info',
      url='http://tobeprovided',
      packages=packages,
      package_data=package_data,
      install_requires=install_requires,
     )
